@@ -15,14 +15,17 @@
 
 static cSatipDevice * SatipDevicesS[SATIP_MAX_DEVICES] = { NULL };
 
+cMutex cSatipDevice::mutexS = cMutex();
+
 cSatipDevice::cSatipDevice(unsigned int indexP)
 : deviceIndexM(indexP),
-  isPacketDeliveredM(false),
+  bytesDeliveredM(0),
   isOpenDvrM(false),
+  checkTsBufferM(false),
   deviceNameM(*cString::sprintf("%s %d", *DeviceType(), deviceIndexM)),
   channelM(),
   createdM(0),
-  mutexM()
+  tunedM()
 {
   unsigned int bufsize = (unsigned int)SATIP_BUFFER_SIZE;
   bufsize -= (bufsize % TS_SIZE);
@@ -42,6 +45,8 @@ cSatipDevice::cSatipDevice(unsigned int indexP)
 cSatipDevice::~cSatipDevice()
 {
   debug1("%s [device %u]", __PRETTY_FUNCTION__, deviceIndexM);
+  // Release immediately any pending conditional wait
+  tunedM.Broadcast();
   // Stop section handler
   StopSectionHandler();
   DELETE_POINTER(pSectionFilterHandlerM);
@@ -211,6 +216,21 @@ bool cSatipDevice::AvoidRecording(void) const
   return SatipConfig.IsOperatingModeLow();
 }
 
+bool cSatipDevice::SignalStats(int &Valid, double *Strength, double *Cnr, double *BerPre, double *BerPost, double *Per, int *Status) const
+{
+  debug16("%s [device %u]", __PRETTY_FUNCTION__, deviceIndexM);
+  Valid = DTV_STAT_VALID_NONE;
+  if (Strength && pTunerM) {
+     *Strength =  pTunerM->SignalStrengthDBm();
+     Valid |= DTV_STAT_VALID_STRENGTH;
+     }
+  if (Status) {
+     *Status = HasLock() ? (DTV_STAT_HAS_SIGNAL | DTV_STAT_HAS_CARRIER | DTV_STAT_HAS_VITERBI | DTV_STAT_HAS_SYNC | DTV_STAT_HAS_LOCK) : DTV_STAT_HAS_NONE;
+     Valid |= DTV_STAT_VALID_STATUS;
+     }
+  return Valid != DTV_STAT_VALID_NONE;
+}
+
 int cSatipDevice::SignalStrength(void) const
 {
   debug16("%s [device %u]", __PRETTY_FUNCTION__, deviceIndexM);
@@ -329,6 +349,7 @@ bool cSatipDevice::MaySwitchTransponder(const cChannel *channelP) const
 
 bool cSatipDevice::SetChannelDevice(const cChannel *channelP, bool liveViewP)
 {
+  cMutexLock MutexLock(&mutexS);  // Global lock to prevent any simultaneous zapping
   debug9("%s (%d, %d) [device %u]", __PRETTY_FUNCTION__, channelP ? channelP->Number() : -1, liveViewP, deviceIndexM);
   if (channelP) {
      cDvbTransponderParameters dtp(channelP->Parameters());
@@ -346,6 +367,8 @@ bool cSatipDevice::SetChannelDevice(const cChannel *channelP, bool liveViewP)
      if (pTunerM && pTunerM->SetSource(server, channelP->Transponder(), *params, deviceIndexM)) {
         channelM = *channelP;
         deviceNameM = cString::sprintf("%s %d %s", *DeviceType(), deviceIndexM, *cSatipDiscover::GetInstance()->GetServerString(server));
+        // Wait for actual channel tuning to prevent simultaneous frontend allocation failures
+        tunedM.TimedWait(mutexS, eTuningTimeoutMs);
         return true;
         }
      }
@@ -357,6 +380,13 @@ bool cSatipDevice::SetChannelDevice(const cChannel *channelP, bool liveViewP)
   return false;
 }
 
+void cSatipDevice::SetChannelTuned(void)
+{
+  debug9("%s () [device %u]", __PRETTY_FUNCTION__, deviceIndexM);
+  // Release immediately any pending conditional wait
+  tunedM.Broadcast();
+}
+
 bool cSatipDevice::SetPid(cPidHandle *handleP, int typeP, bool onP)
 {
   debug12("%s (%d, %d, %d) [device %u]", __PRETTY_FUNCTION__, handleP ? handleP->pid : -1, typeP, onP, deviceIndexM);
@@ -395,7 +425,7 @@ void cSatipDevice::CloseFilter(int handleP)
 bool cSatipDevice::OpenDvr(void)
 {
   debug9("%s [device %u]", __PRETTY_FUNCTION__, deviceIndexM);
-  isPacketDeliveredM = false;
+  bytesDeliveredM = 0;
   tsBufferM->Clear();
   if (pTunerM)
      pTunerM->Open();
@@ -481,13 +511,17 @@ bool cSatipDevice::IsIdle(void)
   return !Receiving();
 }
 
-uchar *cSatipDevice::GetData(int *availableP)
+uchar *cSatipDevice::GetData(int *availableP, bool checkTsBuffer)
 {
   debug16("%s [device %u]", __PRETTY_FUNCTION__, deviceIndexM);
   if (isOpenDvrM && tsBufferM) {
      int count = 0;
-     if (isPacketDeliveredM)
-        SkipData(TS_SIZE);
+     if (bytesDeliveredM) {
+        tsBufferM->Del(bytesDeliveredM);
+        bytesDeliveredM = 0;
+        }
+     if (checkTsBuffer && tsBufferM->Available() < TS_SIZE)
+        return NULL;
      uchar *p = tsBufferM->Get(count);
      if (p && count >= TS_SIZE) {
         if (*p != TS_SYNC_BYTE) {
@@ -501,7 +535,7 @@ uchar *cSatipDevice::GetData(int *availableP)
            info("Skipped %d bytes to sync on TS packet", count);
            return NULL;
            }
-        isPacketDeliveredM = true;
+        bytesDeliveredM = TS_SIZE;
         if (availableP)
            *availableP = count;
         // Update pid statistics
@@ -515,8 +549,7 @@ uchar *cSatipDevice::GetData(int *availableP)
 void cSatipDevice::SkipData(int countP)
 {
   debug16("%s [device %u]", __PRETTY_FUNCTION__, deviceIndexM);
-  tsBufferM->Del(countP);
-  isPacketDeliveredM = false;
+  bytesDeliveredM = countP;
   // Update buffer statistics
   AddBufferStatistic(countP, tsBufferM->Available());
 }
@@ -530,11 +563,12 @@ bool cSatipDevice::GetTSPacket(uchar *&dataP)
      if (cCamSlot *cs = CamSlot()) {
         if (cs->WantsTsData()) {
            int available;
-           dataP = GetData(&available);
-           if (dataP) {
-              dataP = cs->Decrypt(dataP, available);
-              SkipData(available);
-              }
+           dataP = GetData(&available, checkTsBufferM);
+           if (!dataP)
+              available = 0;
+           dataP = cs->Decrypt(dataP, available);
+           SkipData(available);
+           checkTsBufferM = dataP != NULL;
            return true;
            }
         }
