@@ -164,9 +164,6 @@ void cSatipRtsp::Create(void)
      SATIP_CURL_EASY_SETOPT(handleM, CURLOPT_TIMEOUT_MS, (long)eConnectTimeoutMs);
      SATIP_CURL_EASY_SETOPT(handleM, CURLOPT_CONNECTTIMEOUT_MS, (long)eConnectTimeoutMs);
 
-     // Limit download speed (bytes/s)
-     SATIP_CURL_EASY_SETOPT(handleM, CURLOPT_MAX_RECV_SPEED_LARGE, eMaxDownloadSpeedMBits * 131072L);
-
      // Set user-agent
      SATIP_CURL_EASY_SETOPT(handleM, CURLOPT_USERAGENT, *cString::sprintf("vdr-%s/%s (device %d)", PLUGIN_NAME_I18N, VERSION, tunerM.GetId()));
      }
@@ -193,6 +190,22 @@ void cSatipRtsp::Reset(void)
   Create();
 }
 
+bool cSatipRtsp::SetInterface(const char *bindAddrP)
+{
+  debug1("%s (%s) [device %d]", __PRETTY_FUNCTION__, bindAddrP, tunerM.GetId());
+  bool result = true;
+  CURLcode res = CURLE_OK;
+
+  if (handleM && !isempty(bindAddrP)) {
+     SATIP_CURL_EASY_SETOPT(handleM, CURLOPT_INTERFACE, *cString::sprintf("host!%s", bindAddrP));
+     }
+  else {
+     SATIP_CURL_EASY_SETOPT(handleM, CURLOPT_INTERFACE, NULL);
+     }
+
+  return result;
+}
+
 bool cSatipRtsp::Options(const char *uriP)
 {
   debug1("%s (%s) [device %d]", __PRETTY_FUNCTION__, uriP, tunerM.GetId());
