@@ -27,7 +27,6 @@ private:
 
   enum {
     eConnectTimeoutMs      = 1500,  // in milliseconds
-    eMaxDownloadSpeedMBits = 20,    // in megabits per second
   };
 
   cSatipTunerIf &tunerM;
@@ -59,6 +58,7 @@ public:
   cString GetActiveMode(void);
   cString RtspUnescapeString(const char *strP);
   void Reset(void);
+  bool SetInterface(const char *bindAddrP);
   bool Options(const char *uriP);
   bool Setup(const char *uriP, int rtpPortP, int rtcpPortP, bool useTcpP);
   bool SetSession(const char *sessionP);
