@@ -5,6 +5,7 @@
  *
  */
 
+#include <ctype.h>
 #include <getopt.h>
 #include <vdr/plugin.h>
 #include "common.h"
@@ -19,15 +20,15 @@
 #warning "CURL version >= 7.36.0 is recommended"
 #endif
 
-#if defined(APIVERSNUM) && APIVERSNUM < 20301
-#error "VDR-2.3.1 API version or greater is required!"
+#if defined(APIVERSNUM) && APIVERSNUM < 20400
+#error "VDR-2.4.0 API version or greater is required!"
 #endif
 
 #ifndef GITVERSION
 #define GITVERSION ""
 #endif
 
-       const char VERSION[]     = "2.3.0" GITVERSION;
+       const char VERSION[]     = "2.4.0" GITVERSION;
 static const char DESCRIPTION[] = trNOOP("SAT>IP Devices");
 
 class cPluginSatip : public cPlugin {
@@ -90,7 +91,8 @@ const char *cPluginSatip::CommandLineHelp(void)
          "  -S, --single                  set the single model server mode on\n"
          "  -n, --noquirks                disable autodetection of the server quirks\n"
          "  -p, --portrange=<start>-<end> set a range of ports used for the RT[C]P server\n"
-         "                                a minimum of 2 ports per device is required.\n";
+         "                                a minimum of 2 ports per device is required.\n"
+         "  -r, --rcvbuf                  override the size of the RTP receive buffer in bytes\n";
 }
 
 bool cPluginSatip::ProcessArgs(int argc, char *argv[])
@@ -102,6 +104,7 @@ bool cPluginSatip::ProcessArgs(int argc, char *argv[])
     { "trace",    required_argument, NULL, 't' },
     { "server",   required_argument, NULL, 's' },
     { "portrange",required_argument, NULL, 'p' },
+    { "rcvbuf",   required_argument, NULL, 'r' },
     { "detach",   no_argument,       NULL, 'D' },
     { "single",   no_argument,       NULL, 'S' },
     { "noquirks", no_argument,       NULL, 'n' },
@@ -111,7 +114,7 @@ bool cPluginSatip::ProcessArgs(int argc, char *argv[])
   cString server;
   cString portrange;
   int c;
-  while ((c = getopt_long(argc, argv, "d:t:s:p:DSn", long_options, NULL)) != -1) {
+  while ((c = getopt_long(argc, argv, "d:t:s:p:r:DSn", long_options, NULL)) != -1) {
     switch (c) {
       case 'd':
            deviceCountM = strtol(optarg, NULL, 0);
@@ -134,6 +137,9 @@ bool cPluginSatip::ProcessArgs(int argc, char *argv[])
       case 'p':
            portrange = optarg;
            break;
+      case 'r':
+           SatipConfig.SetRtpRcvBufSize(strtol(optarg, NULL, 0));
+           break;
       default:
            return false;
       }
@@ -232,7 +238,7 @@ void cPluginSatip::ParseServer(const char *paramP)
   while (r) {
         r = skipspace(r);
         debug3("%s server[%d]=%s", __PRETTY_FUNCTION__, n, r);
-        cString serverAddr, serverModel, serverFilters, serverDescription;
+        cString sourceAddr, serverAddr, serverModel, serverFilters, serverDescription;
         int serverQuirk = cSatipServer::eSatipQuirkNone;
         int serverPort = SATIP_DEFAULT_RTSP_PORT;
         int n2 = 0;
@@ -243,8 +249,14 @@ void cPluginSatip::ParseServer(const char *paramP)
               switch (n2++) {
                      case 0:
                           {
+                          char *r3 = strchr(r2, '@');
+                          if (r3) {
+                             *r3 = 0;
+                             sourceAddr = r2;
+                             r2 = r3 + 1;
+                             }
                           serverAddr = r2;
-                          char *r3 = strchr(r2, ':');
+                          r3 = strchr(r2, ':');
                           if (r3) {
                              serverPort = strtol(r3 + 1, NULL, 0);
                              serverAddr = serverAddr.Truncate(r3 - r2);
@@ -277,10 +289,10 @@ void cPluginSatip::ParseServer(const char *paramP)
               r2 = strtok_r(NULL, "|", &s2);
               }
         if (*serverAddr && *serverModel && *serverDescription) {
-           debug1("%s ipaddr=%s port=%d model=%s (%s) desc=%s (%d)", __PRETTY_FUNCTION__, *serverAddr, serverPort, *serverModel, *serverFilters, *serverDescription, serverQuirk);
+           debug1("%s srcaddr=%s ipaddr=%s port=%d model=%s (%s) desc=%s (%d)", __PRETTY_FUNCTION__, *sourceAddr, *serverAddr, serverPort, *serverModel, *serverFilters, *serverDescription, serverQuirk);
            if (!serversM)
               serversM = new cSatipDiscoverServers();
-           serversM->Add(new cSatipDiscoverServer(*serverAddr, serverPort, *serverModel, *serverFilters, *serverDescription, serverQuirk));
+           serversM->Add(new cSatipDiscoverServer(*sourceAddr, *serverAddr, serverPort, *serverModel, *serverFilters, *serverDescription, serverQuirk));
            }
         ++n;
         r = strtok_r(NULL, ";", &s);
