@@ -18,7 +18,9 @@ private:
   bool detachedModeM;
   int deviceCountM;
   int operatingModeM;
+  int transportModeM;
   const char *operatingModeTextsM[cSatipConfig::eOperatingModeCount];
+  const char *transportModeTextsM[cSatipConfig::eTransportModeCount];
   int ciExtensionM;
   int cicamsM[MAX_CICAM_COUNT];
   const char *cicamTextsM[CA_SYSTEMS_TABLE_SIZE];
