@@ -40,6 +40,7 @@ cSatipTuner::cSatipTuner(cSatipDeviceIf &deviceP, unsigned int packetLenP)
   externalStateM(),
   timeoutM(eMinKeepAliveIntervalMs),
   hasLockM(false),
+  signalStrengthDBmM(0.0),
   signalStrengthM(-1),
   signalQualityM(-1),
   frontendIdM(-1),
@@ -126,6 +127,7 @@ void cSatipTuner::Action(void)
                break;
           case tsTuned:
                debug4("%s: tsTuned [device %d]", __PRETTY_FUNCTION__, deviceIdM);
+               deviceM->SetChannelTuned();
                reConnectM.Set(eConnectTimeoutMs);
                idleCheck.Set(eIdleCheckTimeoutMs);
                lastIdleStatus = false;
@@ -134,6 +136,7 @@ void cSatipTuner::Action(void)
                   // Quirk for devices without valid reception data
                   if (currentServerM.IsQuirk(cSatipServer::eSatipQuirkForceLock)) {
                      hasLockM = true;
+                     signalStrengthDBmM = eDefaultSignalStrengthDBm;
                      signalStrengthM = eDefaultSignalStrength;
                      signalQualityM = eDefaultSignalQuality;
                      }
@@ -222,12 +225,14 @@ bool cSatipTuner::Connect(void)
            return true;
            }
         }
-     else if (rtspM.Options(*connectionUri)) {
+     else if (rtspM.SetInterface(nextServerM.IsValid() ? *nextServerM.GetSrcAddress() : NULL) && rtspM.Options(*connectionUri)) {
         cString uri = cString::sprintf("%s?%s", *connectionUri, *streamParamM);
         bool useTcp = SatipConfig.IsTransportModeRtpOverTcp() && nextServerM.IsValid() && nextServerM.IsQuirk(cSatipServer::eSatipQuirkRtpOverTcp);
         // Flush any old content
         //rtpM.Flush();
         //rtcpM.Flush();
+        if (useTcp)
+           debug1("%s Requesting TCP [device %d]", __PRETTY_FUNCTION__, deviceIdM);
         if (rtspM.Setup(*uri, rtpM.Port(), rtcpM.Port(), useTcp)) {
            keepAliveM.Set(timeoutM);
            if (nextServerM.IsValid()) {
@@ -261,6 +266,7 @@ bool cSatipTuner::Disconnect(void)
 
   // Reset signal parameters
   hasLockM = false;
+  signalStrengthDBmM = 0.0;
   signalStrengthM = -1;
   signalQualityM = -1;
   frontendIdM = -1;
@@ -330,8 +336,9 @@ void cSatipTuner::ProcessApplicationData(u_char *bufferP, int lengthP)
         // No signal corresponds to 0
         c = strstr(c, ",");
         value = min(atoi(++c), 255);
+        signalStrengthDBmM = (value >= 0) ? 40.0 * (value - 32) / 192.0 - 65.0 : 0.0;
         // Scale value to 0-100
-        signalStrengthM = (value >= 0) ? (value * 100 / 255) : -1;
+        signalStrengthM = (value >= 0) ? value * 100 / 255 : -1;
 
         // lock:
         // lock Set to one of the following values:
@@ -385,8 +392,8 @@ void cSatipTuner::SetupTransport(int rtpPortP, int rtcpPortP, const char *stream
   // Adapt RTP to any transport media change
   if (multicast != rtpM.IsMulticast() || rtpPortP != rtpM.Port()) {
      cSatipPoller::GetInstance()->Unregister(rtpM);
-     rtpM.Close();
      if (rtpPortP >= 0) {
+        rtpM.Close();
         if (multicast)
            rtpM.OpenMulticast(rtpPortP, streamAddrP, sourceAddrP);
         else
@@ -397,12 +404,12 @@ void cSatipTuner::SetupTransport(int rtpPortP, int rtcpPortP, const char *stream
   // Adapt RTCP to any transport media change
   if (multicast != rtcpM.IsMulticast() || rtcpPortP != rtcpM.Port()) {
      cSatipPoller::GetInstance()->Unregister(rtcpM);
-     rtcpM.Close();
      if (rtcpPortP >= 0) {
+        rtcpM.Close();
         if (multicast)
-           rtcpM.OpenMulticast(rtpPortP, streamAddrP, sourceAddrP);
+           rtcpM.OpenMulticast(rtcpPortP, streamAddrP, sourceAddrP);
         else
-           rtcpM.Open(rtpPortP);
+           rtcpM.Open(rtcpPortP);
         cSatipPoller::GetInstance()->Register(rtcpM);
         }
      }
@@ -667,6 +674,12 @@ int cSatipTuner::SignalStrength(void)
   return signalStrengthM;
 }
 
+double cSatipTuner::SignalStrengthDBm(void)
+{
+  debug16("%s [device %d]", __PRETTY_FUNCTION__, deviceIdM);
+  return signalStrengthDBmM;
+}
+
 int cSatipTuner::SignalQuality(void)
 {
   debug16("%s [device %d]", __PRETTY_FUNCTION__, deviceIdM);
