@@ -69,6 +69,7 @@ public:
   void Set(cSatipServer *serverP, const int transponderP) { serverM = serverP; transponderM = transponderP; }
   void Reset(void) { serverM = NULL; transponderM = 0; }
   cString GetAddress(void) { return serverM ? cSatipDiscover::GetInstance()->GetServerAddress(serverM) : ""; }
+  cString GetSrcAddress(void) { return serverM ? cSatipDiscover::GetInstance()->GetSourceAddress(serverM) : ""; }
   int GetPort(void) { return serverM ? cSatipDiscover::GetInstance()->GetServerPort(serverM) : SATIP_DEFAULT_RTSP_PORT; }
   cString GetInfo(void) { return cString::sprintf("server=%s deviceid=%d transponder=%d", serverM ? "assigned" : "null", deviceIdM, transponderM); }
 };
@@ -77,16 +78,17 @@ class cSatipTuner : public cThread, public cSatipTunerStatistics, public cSatipT
 {
 private:
   enum {
-    eDummyPid               = 100,
-    eDefaultSignalStrength  = 15,
-    eDefaultSignalQuality   = 224,
-    eSleepTimeoutMs         = 250,   // in milliseconds
-    eStatusUpdateTimeoutMs  = 1000,  // in milliseconds
-    ePidUpdateIntervalMs    = 250,   // in milliseconds
-    eConnectTimeoutMs       = 5000,  // in milliseconds
-    eIdleCheckTimeoutMs     = 15000, // in milliseconds
-    eTuningTimeoutMs        = 20000, // in milliseconds
-    eMinKeepAliveIntervalMs = 30000  // in milliseconds
+    eDummyPid                 = 100,
+    eDefaultSignalStrengthDBm = -25,
+    eDefaultSignalStrength    = 224,
+    eDefaultSignalQuality     = 15,
+    eSleepTimeoutMs           = 250,   // in milliseconds
+    eStatusUpdateTimeoutMs    = 1000,  // in milliseconds
+    ePidUpdateIntervalMs      = 250,   // in milliseconds
+    eConnectTimeoutMs         = 5000,  // in milliseconds
+    eIdleCheckTimeoutMs       = 15000, // in milliseconds
+    eTuningTimeoutMs          = 20000, // in milliseconds
+    eMinKeepAliveIntervalMs   = 30000  // in milliseconds
   };
   enum eTunerState { tsIdle, tsRelease, tsSet, tsTuned, tsLocked };
   enum eStateMode { smInternal, smExternal };
@@ -114,6 +116,7 @@ private:
   cVector<eTunerState> externalStateM;
   int timeoutM;
   bool hasLockM;
+  double signalStrengthDBmM;
   int signalStrengthM;
   int signalQualityM;
   int frontendIdM;
@@ -148,6 +151,7 @@ public:
   bool Close(void);
   int FrontendId(void);
   int SignalStrength(void);
+  double SignalStrengthDBm(void);
   int SignalQuality(void);
   bool HasLock(void);
   cString GetSignalStatus(void);
